==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/bg.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Външни хранилища",
    "Personal" : "Личен",
    "System" : "Системен",
    "Grant access" : "Разреши достъп",
    "Generate keys" : "Генериране на криптографски ключове",
    "Error generating key pair" : "Грешка при генериране на криптографски ключове",
    "All users. Type to select user or group." : "Всички потребители. Пишете, за да изберете потребител или група.",
    "(group)" : "(група)",
    "Saved" : "Запазено",
    "Saving..." : "Запазване...",
    "Save" : "Запис",
    "external-storage" : "външно хранилище",
    "Username" : "Потребител",
    "Password" : "Парола",
    "Invalid mount point" : "Невалиден път за мониторане на файлова система",
    "%s" : "%s",
    "Secret key" : "Секретен ключ",
    "None" : "Няма",
    "OAuth1" : "OAuth1",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "API key" : "API ключ",
    "Public key" : "Публичен ключ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Сървър",
    "Port" : "Порт",
    "Region" : "Регион",
    "Enable SSL" : "Включи SSL",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Външна подпапка",
    "Secure https://" : "Подсигурен https://",
    "FTP" : "FTP",
    "Host" : "Сървър",
    "Secure ftps://" : "Сигурен ftps://",
    "Local" : "Локално",
    "Location" : "Местоположение",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Споделяне",
    "Domain" : "Домейн",
    "SMB / CIFS using OC login" : "SMB / CIFS използвайки OC профил",
    "Username as share" : "Потребителско име като споделена папка",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Име на услугата",
    "No external storage configured" : "Няма настроени външни хранища",
    "You can add external storages in the personal settings" : "Външни хранилища се добавят от личните настройки",
    "Name" : "Име",
    "Storage type" : "Тип хранилище",
    "Scope" : "Обхват",
    "Check for changes" : "Проверка за промени",
    "Never" : "Никога",
    "Folder name" : "Име на папката",
    "External storage" : "Външно хранилище",
    "Configuration" : "Настройки",
    "Available for" : "Достъпно за",
    "Add storage" : "Добави хранилище",
    "Advanced settings" : "Разширени настройки",
    "Delete" : "Изтрий",
    "Allow users to mount external storage" : "Разреши на потребителите да монтират външни хранилища",
    "Allow users to mount the following external storage" : "Разреши на потребителите да монтират следното външно хранилище"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/bg.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Външни хранилища",
    "Personal" : "Личен",
    "System" : "Системен",
    "Grant access" : "Разреши достъпa",
    "Generate keys" : "Генериране на криптографски ключове",
    "Error generating key pair" : "Грешка при генериране на криптографски ключове",
    "All users. Type to select user or group." : "Всички потребители. Пишете, за да изберете потребител или група.",
    "(group)" : "(група)",
    "Enable encryption" : "Включване на криптиране",
    "Check for changes" : "Проверка за промени",
    "Never" : "Никога",
    "Read only" : "Само за четене",
    "Delete" : "Изтрий",
    "Saved" : "Запазено",
    "Saving..." : "Запазване...",
    "Save" : "Запис",
    "external-storage" : "външно хранилище",
    "Username" : "Потребител",
    "Password" : "Парола",
    "Invalid mount point" : "Невалиден път за мониторане на файлова система",
    "%s" : "%s",
    "Secret key" : "Секретен ключ",
    "None" : "Няма",
    "OAuth1" : "OAuth1",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Domain" : "Домейн",
    "API key" : "API ключ",
    "Username and password" : "Потребител и парола",
    "Public key" : "Публичен ключ",
    "Private key" : "Частен ключ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Хост",
    "Port" : "Порт",
    "Region" : "Регион",
    "Enable SSL" : "Включи SSL",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Външна подпапка",
    "Secure https://" : "Подсигурен https://",
    "FTP" : "FTP",
    "Host" : "Хост",
    "Secure ftps://" : "Сигурен ftps://",
    "Local" : "Локално",
    "Location" : "Местоположение",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Споделяне",
    "Show hidden files" : "Показване и на скрити файлове",
    "SMB / CIFS using OC login" : "SMB / CIFS използвайки OC профил",
    "Username as share" : "Потребителско име като споделена папка",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Име на услугата",
    "Name" : "Име",
    "Storage type" : "Тип хранилище",
    "Scope" : "Обхват",
    "Open documentation" : "Отвори документацията",
    "Folder name" : "Име на папката",
    "External storage" : "Външно хранилище",
    "Authentication" : "Удостоверяване",
    "Configuration" : "Настройки",
    "Available for" : "Достъпно за",
    "Add storage" : "Добави хранилище",
    "Advanced settings" : "Допълнителни настройки",
    "Allow users to mount external storage" : "Разреши на потребителите да монтират външни хранилища"
},
"nplurals=2; plural=(n != 1);");
